@@ -19,7 +19,7 @@ use strict;
 use Carp;
 use vars qw($VERSION $FIELD_NAME);
 
-$VERSION = "1.49";
+$VERSION = "1.53";
 
 my $MAIL_FROM = 'KEEP';
 my %HDR_LENGTHS = ();
@@ -152,10 +152,12 @@ sub _tag_case
 {
  my $tag = shift;
 
+ # Bug in unicode \U, perl 5.8.0 breaks when casing utf8 in regex
+ utf8::downgrade($tag) if $] eq 5.008;
+
  $tag =~ s/:\Z//o;
 
- # Change the case of the tag
- # eq Message-Id
+ # Change the casing of the tag, eg "Message-Id"
  $tag =~ s/\b([a-z]+)/\L\u$1/gio;
  $tag =~ s/\b([b-df-hj-np-tv-z]+|MIME)\b/\U$1/gio
 	if $tag =~ /-/;
